"
COPYRIGHT (c) 2020-2022 LabWare
"
"{ Package: 'stx:goodies/monticello' }"

"{ NameSpace: Smalltalk }"

Object subclass:#MCSnapshotOptions
	instanceVariableNames:'includeExtrasForSTX exporter importer'
	classVariableNames:''
	poolDictionaries:''
	category:'SCM-Monticello-Base'
!

!MCSnapshotOptions class methodsFor:'documentation'!

copyright
"
COPYRIGHT (c) 2020-2022 LabWare


"
! !

!MCSnapshotOptions methodsFor:'accessing'!

exporter
    "Return an instance of source porter (a kind of AutomagicSourcePorter)
     to apply to method's source when writing a snapshot - that is,
     when exported from Smalltalk/X to Monticello / Tonel.

     Defaults to use base AutomagicSourcePorter instance to:

      * Strip namespaces if any
      * Replace end-of-line comments with normal one.
      * Replace (St/X) 'Block' with (Pharo / Squeak / Cuis) 'BlockClosure'

     Nor Squeak nor Pharo does support either of the above, so this is
     safe and convenient choice."
    
    exporter isNil ifTrue: [
        exporter := AutomagicSourcePorter new.
         
        "/ JV@2021-05-04: not sure this is a good idea,
        "/ but all the MC-related code is used almost 
        "/ exclusively in Squeak / Pharo / Cuis world, so
        "/ which have BlockClosure, not Block like St/X.
        "/ 
        "/ Monticello / Tonel is also used with GS but there
        "/ BlockClosure is an abstract superclass, so the rewrite
        "/ is also valid.
        "/ 
        "/ For the sake of completenes:
        "/ In VA, there's no BlockClosure, they call it `Block`. But then, 
        "/ in VA Tonel or Monticello is not used that extensively
        "/ and if so, they would have to have a way to deal with that
        "/ anyway.
        
        exporter klassMap at: #Block put: #BlockClosure.
    ].
    ^ exporter

    "Modified: / 04-05-2021 / 13:03:09 / Jan Vrany <jan.vrany@labware.com>"
    "Modified (comment): / 04-05-2021 / 22:05:18 / Jan Vrany <jan.vrany@labware.com>"
!

exporter: porterInstance 
    "
     Set the porter instance to use when writing snapshot. Set to
     `nil` to disable any source code rewriting.

     For details, see #porter comment."
    
    exporter := porterInstance.

    "Modified (comment): / 02-07-2020 / 21:24:12 / Jan Vrany <jan.vrany@labware.com>"
!

importer
    "Return an instance of source porter (a kind of AutomagicSourcePorter)
     to apply to method's source reading from snapshot - that is,
     when loaded into Smalltalk/X from Monticello / Tonel.

     Defaults to use base AutomagicSourcePorter instance to:

      * Replace (Pharo / Squeak / Cuis) 'BlockClosure with (St/X) 'Block'.
    "

    importer isNil ifTrue: [
        importer := AutomagicSourcePorter new.
         
        "/ JV@2021-05-04: not sure this is a good idea,
        "/ but all the MC-related code is used almost 
        "/ exclusively in Squeak / Pharo / Cuis world, so
        "/ which have BlockClosure, not Block like St/X.
        "/ 
        "/ Monticello / Tonel is also used with GS but there
        "/ BlockClosure is an abstract superclass, so the rewrite
        "/ is also valid.
        "/ 
        "/ For the sake of completenes:
        "/ In VA, there's no BlockClosure, they call it `Block`. But then, 
        "/ in VA Tonel or Monticello is not used that extensively
        "/ and if so, they would have to have a way to deal with that
        "/ anyway.
        
        importer klassMap at: #BlockClosure put: #Block.
    ].
    ^ importer

    "Modified: / 22-09-2022 / 11:29:34 / Jan Vrany <jan.vrany@labware.com>"
!

importer: porterInstance 
    "
     Set the porter instance to use when reading snapshot. Set to
     `nil` to disable any source code rewriting.

     For details, see #importer comment."
    
    importer := porterInstance.

    "Modified (comment): / 02-07-2020 / 21:24:12 / Jan Vrany <jan.vrany@labware.com>"
!

includeExtrasForSTX    
    
    "/ do not default to true here, as the version is snapshotted twice in order to
    "/ update the version-strings, and we don not need this stuff in the first round!!
    ^ includeExtrasForSTX ? false

    "Modified: / 07-09-2015 / 15:22:36 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

includeExtrasForSTX:aBoolean
    includeExtrasForSTX := aBoolean.
! !

!MCSnapshotOptions class methodsFor:'documentation'!

version_HG

    ^ '$Changeset: <not expanded> $'
! !

